==> Data-MoneyCurrency-0.21.tar.gz: Data-MoneyCurrency-0.21/README.md <==
[![Build Status](https://travis-ci.org/OpenCageData/perl5-Data-MoneyCurrency.svg?branch=master)](https://travis-ci.org/OpenCageData/perl5-Data-MoneyCurrency)
[![CPAN](https://img.shields.io/cpan/v/Data-MoneyCurrency.svg?style=flat-square)](https://metacpan.org/pod/Data::MoneyCurrency)
[![Twitter Follow](https://img.shields.io/twitter/follow/OpenCage?label=Follow%20OpenCage&style=social)](https://twitter.com/opencage)

# Data::MoneyCurrency

Get currency information for different currencies and countries

## Usage

For docs please see [the Data::MoneyCurrency page on search.metacpan.org](https://metacpan.org/pod/Data::MoneyCurrency)
or `perldoc Data::MoneyCurrency`.

## INSTALLATION

To install this module, use cpanm

	cpanm Data::MoneyCurrency

## SUPPORT AND DOCUMENTATION

After installing, you can find documentation for this module with the
perldoc command.

    perldoc Data::MoneyCurrency

You can also look for information at:

    GitHub issues (report bugs here)
        https://github.com/OpenCageData/perl5-Data-MoneyCurrency

    Meta CPAN
        https://metacpan.org/pod/Data::MoneyCurrency


## LICENSE AND COPYRIGHT

Copyright OpenCage GmbH
<cpan@opencagedata.com>

This is licensed under the MIT license, and includes code from the
RubyMoney/Money module, which is also licensed under the MIT license.

### Who is OpenCage GmbH?

<a href="https://opencagedata.com"><img src="opencage_logo_300_150.png"></a>

We run the [OpenCage Geocoder](https://opencagedata.com). Learn more [about us](https://opencagedata.com/about). 

We also run [Geomob](https://thegeomob.com), a series of regular meetups for location based service creators, where we do our best to highlight geoinnovation. If you like geo stuff, you will probably enjoy [the Geomob podcast](https://thegeomob.com/podcast/).

==> Data-MoneyCurrency-0.23.tar.gz: Data-MoneyCurrency-0.23/README.md <==
[![Build Status](https://travis-ci.org/OpenCageData/perl5-Data-MoneyCurrency.svg?branch=master)](https://travis-ci.org/OpenCageData/perl5-Data-MoneyCurrency)
[![CPAN](https://img.shields.io/cpan/v/Data-MoneyCurrency.svg?style=flat-square)](https://metacpan.org/pod/Data::MoneyCurrency)
[![Twitter Follow](https://img.shields.io/twitter/follow/OpenCage?label=Follow%20OpenCage&style=social)](https://twitter.com/opencage)

# Data::MoneyCurrency

Get currency information for different currencies and countries

## Usage

For docs please see [the Data::MoneyCurrency page on search.metacpan.org](https://metacpan.org/pod/Data::MoneyCurrency)
or `perldoc Data::MoneyCurrency`.

## INSTALLATION

To install this module, use cpanm

	cpanm Data::MoneyCurrency

## SUPPORT AND DOCUMENTATION

After installing, you can find documentation for this module with the
perldoc command.

    perldoc Data::MoneyCurrency

You can also look for information at:

    GitHub issues (report bugs here)
        https://github.com/OpenCageData/perl5-Data-MoneyCurrency

    Meta CPAN
        https://metacpan.org/pod/Data::MoneyCurrency


## LICENSE AND COPYRIGHT

Copyright OpenCage GmbH
<cpan@opencagedata.com>

This is licensed under the MIT license, and includes code from the
RubyMoney/Money module, which is also licensed under the MIT license.

### Who is OpenCage GmbH?

<a href="https://opencagedata.com"><img src="opencage_logo_300_150.png"></a>

We run a worldwide [geocoding API](https://opencagedata.com/api) and [geosearch](https://opencagedata.com/geosearch) service based on open data. 
Learn more [about us](https://opencagedata.com/about). 

We also organize [Geomob](https://thegeomob.com), a series of regular meetups for location based service creators, where we do our best to highlight geoinnovation. If you like geo stuff, you will probably enjoy [the Geomob podcast](https://thegeomob.com/podcast/).
